#!/bin/bash

# This helper script will handle deploying a managed apache airflow (mwaa) instance
#
# /scripts/deploy-airflow.sh
#

set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars
echo "s3_bucket_arn = \"${DAGS_S3_BUCKET_ARN}\"" >> ${tfAdditionalVarsFile}
echo "aws_mwaa_execution_role_arn = \"${MWAA_EXECUTION_ROLE_ARN}\"" >> ${tfAdditionalVarsFile}
if [ -n "${REQUIREMENTS_S3_OBJECTS_VERSION}" ]; then
  echo "requirements_s3_object_version = \"${REQUIREMENTS_S3_OBJECTS_VERSION}\"" >> ${tfAdditionalVarsFile}
fi

terraform_init

terraform_plan
terraform_apply
terraform_output

print_header "Dump terraform output"
cat output.json

print_header "Dump output to ConfigMap"

arnConfigMapName=${namingPrefix}-arn
terraform_get mwaa_arn arnValue
terraform_get mwaa_environment_name mwaaEnvironmentName
terraform_get mwaa_webserver_endpoint webserverValue

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  MWAA_ENVIRONMENT_NAME: ${mwaaEnvironmentName}
  WEBSERVER_ENDPOINT: ${webserverValue}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

if [ "${INGRESS_ENABLED}x" == "truex" ]; then
  serviceName=${namingPrefix}

  cat >/tmp/external-name-svc.yaml <<EOF
apiVersion: v1
kind: Service
metadata:
  name: ${serviceName}
spec:
  externalName: ${webserverValue}
  type: ExternalName
EOF

  run_cmd cat "/tmp/external-name-svc.yaml"
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/external-name-svc.yaml
fi

cprint "$0 done "
